@@ -19,6 +19,7 @@
 #include "createaccount.h"
 #include "ownclouddialog.h"
 #include "lib/kaccountsuiplugin.h"
+#include "lib/core.h"
 #include "uipluginsmanager.h"
 
 #include <QDebug>
@@ -58,53 +59,20 @@ CreateAccount::CreateAccount(const QString &providerName, QObject* parent)
 void CreateAccount::start()
 {
     qDebug() << m_providerName;
-    if (m_providerName == QLatin1String("owncloud")) {
-        QMetaObject::invokeMethod(this, "processSessionOwncloud");
-    } else {
-        QMetaObject::invokeMethod(this, "processSession");
-    }
-}
-
-void CreateAccount::processSessionOwncloud()
-{
-    OwncloudDialog* dialog = new OwncloudDialog();
-    int result = dialog->exec();
-    if (result == QDialog::Rejected) {
-        setError(-1);
-        // this should not be user visible string
-        setErrorText("Dialog was canceled");
-        emitResult();
-        return;
-    }
-
-    SignOn::IdentityInfo info;
-    info.setUserName(dialog->username());
-    info.setSecret(dialog->password());
-    info.setCaption(m_providerName);
-    info.setAccessControlList(QStringList(QLatin1String("*")));
-    info.setType(SignOn::IdentityInfo::Application);
-
-    m_identity = SignOn::Identity::newIdentity(info, this);
-    m_identity->storeCredentials();
-    m_done = true;
-
-    m_account = m_manager->createAccount(m_providerName);
-    m_account->setValue("dav/host", dialog->host());
-
-    Accounts::Service service;
-    m_accInfo = new Accounts::AccountService(m_account, service, this);
-
-    connect(m_identity, SIGNAL(info(SignOn::IdentityInfo)), SLOT(info(SignOn::IdentityInfo)));
-    m_identity->queryInfo();
+    QMetaObject::invokeMethod(this, "processSession");
 }
 
 void CreateAccount::processSession()
 {
     m_account = m_manager->createAccount(m_providerName);
     Accounts::Service service;
+    if (m_account->services().size() == 1) {
+        service = m_account->services().at(0);
+    }
     m_accInfo = new Accounts::AccountService(m_account, service, this);
 
     const QString pluginName = m_account->provider().pluginName();
+    qDebug() << "Looking for plugin" << pluginName;
     if (!pluginName.isEmpty()) {
         loadPluginAndShowDialog(pluginName);
     } else {
@@ -146,18 +114,13 @@ void CreateAccount::loadPluginAndShowDialog(const QString &pluginName)
     }
 
     connect(ui, &KAccountsUiPlugin::success, this, &CreateAccount::pluginFinished, Qt::UniqueConnection);
-
     connect(ui, &KAccountsUiPlugin::error, this, &CreateAccount::pluginError, Qt::UniqueConnection);
 
-    ui->init(KAccountsUiPlugin::NewAccountDialog);
-
-    // When the plugin has finished building the UI, show it right away
-    connect(ui, &KAccountsUiPlugin::uiReady, ui, &KAccountsUiPlugin::showNewAccountDialog, Qt::UniqueConnection);
-
     ui->setProviderName(m_providerName);
+    ui->init(KAccountsUiPlugin::NewAccountDialog);
 }
 
-void CreateAccount::pluginFinished(const QString &screenName, const QString &secret, const QVariantMap &/*data*/)
+void CreateAccount::pluginFinished(const QString &screenName, const QString &secret, const QVariantMap &data)
 {
     // Set up the new identity
     SignOn::IdentityInfo info;
@@ -168,6 +131,16 @@ void CreateAccount::pluginFinished(const QString &screenName, const QString &sec
     info.setAccessControlList(QStringList(QLatin1String("*")));
     info.setType(SignOn::IdentityInfo::Application);
 
+    Q_FOREACH (const QString &key, data.keys()) {
+        // If a key with __service/ prefix exists and its value is false,
+        // add it to m_disabledServices which will later be used for disabling
+        // the services contained in that list
+        if (key.startsWith(QLatin1String("__service/")) && !data.value(key).toBool()) {
+            m_disabledServices << key.mid(10);
+        }
+        m_account->setValue(key, data.value(key).toString());
+    }
+
     m_identity = SignOn::Identity::newIdentity(info, this);
     connect(m_identity, SIGNAL(info(SignOn::IdentityInfo)), SLOT(info(SignOn::IdentityInfo)));
 
@@ -234,14 +207,15 @@ void CreateAccount::info(const SignOn::IdentityInfo &info)
         m_account->setValue(base + i.key(), i.value());
     }
 
-    m_account->setEnabled(true);
 
     Accounts::ServiceList services = m_account->services();
     Q_FOREACH(const Accounts::Service &service, services) {
         m_account->selectService(service);
-        m_account->setEnabled(true);
+        m_account->setEnabled(m_disabledServices.contains(service.name()) ? false : true);
     }
 
+    m_account->selectService();
+    m_account->setEnabled(true);
     m_account->sync();
     connect(m_account, &Accounts::Account::synced, this, &CreateAccount::emitResult);
 }
