@@ -21,6 +21,8 @@
 
 #include <kjob.h>
 
+#include <QStringList>
+
 namespace Accounts
 {
     class Account;
@@ -48,7 +50,6 @@ public:
     void start() Q_DECL_OVERRIDE;
 
 private Q_SLOTS:
-    void processSessionOwncloud();
     void processSession();
     void sessionError(const SignOn::Error &signOnError);
     void sessionResponse(const SignOn::SessionData &data);
@@ -63,6 +64,7 @@ private:
     void loadPluginAndShowDialog(const QString &pluginName);
 
     QString m_providerName;
+    QStringList m_disabledServices;
     Accounts::Manager *m_manager;
     Accounts::Account *m_account;
     Accounts::AccountService *m_accInfo;
